@@ -16,6 +16,7 @@ import types
 import shutil
 from copy import deepcopy
 import traceback
+import ctypes
 import re
 from subprocess import Popen
 from subprocess import PIPE
@@ -1148,7 +1149,58 @@ def RecoverableImplementation(obj, executor, function, *args, **kwargs):
 				pass
 
 		#  We failed to resolve the error. Die
-		raise FailedErrorResolution(f"Tried and failed to resolve: {e} STACK: {executor.errorResolutionStack}.")
+		sys.tracebacklimit = 0 # traceback is NOT helpful here.
+		raise FailedErrorResolution(f"Tried and failed to resolve: {e} STACK: {executor.errorResolutionStack}. See earlier logs (in debug) for traceback.")
+
+
+# ExecutorTracker is a global singleton which keeps a record of all Executors that have been launched.
+# This can be abused quite a bit, so please try to restrict usage of this to only:
+# * Ease of use global functions
+#
+# Thanks! 
+class ExecutorTracker:
+	def __init__(this):
+		# Singletons man...
+		if "instance" not in ExecutorTracker.__dict__:
+			logging.debug(f"Creating new ExecutorTracker: {this}")
+			ExecutorTracker.instance = this
+		else:
+			return None
+
+		this.executors = [None]
+
+	@staticmethod
+	def Instance():
+		if "instance" not in ExecutorTracker.__dict__:
+			ExecutorTracker()
+		return ExecutorTracker.instance
+
+	@staticmethod
+	def Push(executor):
+		ExecutorTracker.Instance().executors.append(executor)
+
+		# Adding the executor to our list here increases its reference count.
+		# Executors are supposed to remove themselves from this list when they are deleted.
+		# A python object cannot be deleted if it has references.
+		# Thus, we forcibly decrease the reference count and rely on Exectuor's self-reporting to avoid accessing deallocated memory.
+		# This appears to cause segfaults on some systems, so we'll just live with the fact that Executors will never be destroyed.
+		# If you want your executor to stop being tracked, do it yourself. :(
+		#
+		# ctypes.pythonapi.Py_DecRef(ctypes.py_object(executor))
+
+		logging.debug(f"Now tracking Executor: {executor}")
+
+	@staticmethod
+	def Pop(executor):
+		try:
+			ExecutorTracker.Instance().executors.remove(executor)
+			logging.debug(f"No longer tracking Executor: {executor}")
+		except:
+			pass
+
+	@staticmethod
+	def GetLatest():
+		return ExecutorTracker.Instance().executors[-1]
 
 
 # Executor: a base class for user interfaces.
@@ -1210,10 +1262,18 @@ class Executor(DataContainer, Functor):
 		this.defaultConfigFile = None
 		this.defaultPackageType = ""
 
+		# Track *this globally
+		ExecutorTracker.Instance().Push(this)
+
 		this.Configure()
 		this.RegisterIncludedClasses()
 		this.AddArgs()
 
+	# Destructors do not work reliably in python.
+	# NOTE: you CANNOT delete *this without first Pop()ing it from the ExecutorTracker.
+	# def __del__(this):
+	# 	ExecutorTracker.Instance().Pop(this)
+
 
 	# Adapter for @recoverable.
 	# See Recoverable.py for details
@@ -1649,6 +1709,15 @@ class Executor(DataContainer, Functor):
 	######## END: Fetch Locations ########
 
 
+# Global Fetch() function.
+# Uses the latest registered Executor
+def Fetch(varName, default=None, fetchFrom=None, start=True, attempted=None):
+    return ExecutorTracker.GetLatest().Fetch(varName, default, fetchFrom, start, attempted)
+
+# Ease-of-use wrapper for the global Fetch()
+def f(varName, default=None, fetchFrom=None, start=True, attempted=None):
+    Fetch(varName, default, fetchFrom, start, attempted)
+
 def METHOD_PENDING_POPULATION(obj, *args, **kwargs):
 	raise MethodPendingPopulation("METHOD PENDING POPULATION")
 
@@ -1931,7 +2000,7 @@ class StandardFunctor(Functor):
 				logging.debug(f"| {line}")  # [:-1] to strip excessive new lines.
 
 		if (p.returncode is not None and p.returncode):
-			raise CommandUnsuccessful(f"Command returned {p.returncode}")
+			raise CommandUnsuccessful(f"Command returned {p.returncode}: {command}")
 		
 		logging.debug(f"================ Completed command: {command} ================")
 		if (saveout):
